@@ -1594,8 +1594,9 @@ srl_event_is_reported (SRLEvent *event)
     if (srle_has_type (event, SRL_EVENT_WINDOW_DEACTIVATE))
 	rv = FALSE;
 
-    if (rv && (srle_is_for_focused_acc (event) ||
-	      srle_is_for_watched_acc (event)))
+    if (rv && (srle_has_type (event, SRL_EVENT_FOCUS) ||
+	      srle_is_for_watched_acc (event) ||
+	      srle_is_for_focused_acc (event)))
     {
 	srl_assert (last_info);
 	if (srle_has_type (event, SRL_EVENT_TEXT_CHANGED_DELETE))
@@ -1608,12 +1609,15 @@ srl_event_is_reported (SRLEvent *event)
 	else
 	    srl_set_info (event->acc_ev->source, last_info);
 
-	if (srle_is_for_focused_acc (event))
-	    if (last_info != &last_info_focus)
-		last_info_focus = *last_info;
 	if (srle_is_for_watched_acc (event))
+	{
 	    if (last_info != &last_info_watched)
 		last_info_watched = *last_info;
+	}else
+	{
+	    if (last_info != &last_info_focus)
+		last_info_focus = *last_info;
+	}
     }
     
     if (srle_acc_has_role (event, SPI_ROLE_EDITBAR))
